@@ -17,7 +17,10 @@ test_that("Setup with seed works (use 2 for testing)", {
 # })
 
 test_that("Don't restart if FALSE", {
-  expect_message(jlmerclusterperm_setup(restart = FALSE), "already running")
+  setup_is_ok <- julia_setup_ok()
+  if (setup_is_ok) {
+    expect_message(jlmerclusterperm_setup(restart = FALSE), "already running")
+  }
 })
 
 test_that("RNG initializes to seed=1 counter=0", {
